==> downloads.html?file=gigkalender_v1.2.64.zip: gigkalender/calendar/backend_showGig.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  echo '<p class="Headline">'.$L_Headline35.':</p>';
  if ( !loggedIn() ) echo $L_003;
  else
  {
    // Inhalt hier einfügen
    //$Timestamp = $_REQUEST['timestamp'];
    $SQL_Befehl = "SELECT * FROM ".$prefix."gigs Where GigID = '$id'";
    $resultat = mysql_db_query($db_name, $SQL_Befehl);
    while ($row = mysql_fetch_array($resultat))
    {
      extract($row);
      $Tag = date('d', $GigDate);
      $Monat = date('m', $GigDate);
      $Jahr = date('Y', $GigDate);
    }
    echo '<table summary="ShowGig" class="Tabelle_GigAnzeigen">
            <tr>
              <td>'.$L_GigDate.':</td>
              <td>'.$Tag.'.'.$Monat.'.'.$Jahr.'</td>
            </tr>
            <tr>
              <td>'.$L_GigLocation.':</td>
              <td>'.getLocationString ($GigCountry, $GigDistrict, $GigPostalCode, $GigCity ).'</td>
            </tr>
            <tr>
              <td>'.$L_GigVenue.':</td>
              <td>'.$GigVenue.'</td>
            </tr>
            <tr>
              <td>'.$L_GigVenueURL.':</td>
              <td>'.$GigVenueURL.'</td>
            </tr>
            <tr>
              <td>'.$L_GigEvent.':</td>
              <td>'.$GigEvent.'</td>
            </tr>
            <tr>
              <td>'.$L_GigEventURL.':</td>
              <td>'.$GigEventURL.'</td>
            </tr>
            <tr>
              <td>'.$L_GigEntranceFee.':</td>
              <td>'.$GigEntranceFee.'</td>
            </tr>
            <tr>
              <td>'.$L_GigOrganizer.':</td>
              <td>'.$GigOrganizer.'</td>
            </tr>
            <tr>
              <td>'.$L_GigOrganizerURL.':</td>
              <td>'.$GigOrganizerURL.'</td>
            </tr>
            <tr>
              <td>'.$L_GigArtist.':</td>
              <td>'.$GigArtist.'</td>
            </tr>
            <tr>
              <td>'.$L_GigArtistURL.':</td>
              <td>'.$GigArtistURL.'</td>
            </tr>
            <tr>
              <td>'.$L_GigLineup.':</td>
              <td>'.$GigLineup.'</td>
            </tr>
            <tr>
              <td>'.$L_GigVisitors.':</td>
              <td>'.$GigVisitors.'</td>
            </tr>
            <tr>
              <td>'.$L_GigStageBuilding.':</td>
              <td>'.$GigStageBuilding.'</td>
            </tr>
            <tr>
              <td>'.$L_GigBeginning.':</td>
              <td>'.$GigBeginning.'</td>
            </tr>
            <tr>
              <td>'.$L_GigDuration.':</td>
              <td>'.$GigDuration.'</td>
            </tr>
            <tr>
              <td>'.$L_GigEnding.':</td>
              <td>'.$GigEnding.'</td>
            </tr>
            <tr>
              <td>'.$L_GigNotes.':</td>
              <td>'.$GigNotes.'</td>
            </tr>
            <tr>
              <td>'.$L_GigStatus.':</td>
              <td>'.${'L_GigStatus'.$GigStatus}.'</td>
            </tr>
            <tr>
              <td>'.$L_GigIsPrivate.':</td>
              <td>';
                if ( $GigIsPrivate ) echo $L_091;
                else echo $L_092;
                echo '
              </td>
            </tr>
            <tr>
              <td>'.$L_GigDateOfAdding.':</td>
              <td>'.DatumMitUhrzeitAusTimestamp($GigDateOfAdding);
                if ($GigAddedFrom) echo ' (';
                echo $GigAddedFrom;
                if ($GigAddedFrom) echo ')';
                echo'
              </td>
            </tr>
            <tr>
              <td>'.$L_GigDateOfLastEdit.':</td>
              <td>'.DatumMitUhrzeitAusTimestamp($GigDateOfLastEdit);
                if ($GigLastEditor) echo ' (';
                echo $GigLastEditor;
                if ($GigLastEditor) echo ')';
                echo'
              </td>
            </tr>
          </table>
          <a href="javascript:window.print()"><img src="images/print.gif" alt="'.$L_008.'" title="'.$L_008.'" /></a>
          <br />
          <input type="button" value="'.$L_Button04.'" onclick="history.go(-1)" class="button" />';
        // Inhalt zuende
  }
?>

==> downloads.html?file=gigkalender_v1.2.80_146.zip: gigkalender/calendar/backend_showGig.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  echo '<p class="Headline">'.$L_Headline35.':</p>';
  if ( !loggedIn() ) echo $L_003;
  else
  {
    // Inhalt hier einfügen
    //$Timestamp = $_REQUEST['timestamp'];
    $SQLQuery = "SELECT * FROM ".$prefix."gigs Where GigID = '$id'";
    $Result = mysqli_query($db, $SQLQuery);
    while ($row = mysqli_fetch_array($Result))
    {
      extract($row);
      $Day = date('d', $GigDate);
      $Month = date('m', $GigDate);
      $Year = date('Y', $GigDate);
    }
    echo '<table summary="ShowGig" class="Tabelle_GigAnzeigen">
            <tr>
              <td>'.$L_GigDate.':</td>
              <td>'.$Day.'.'.$Month.'.'.$Year.'</td>
            </tr>
            <tr>
              <td>'.$L_GigLocation.':</td>
              <td>'.getLocationString ($GigCountry, $GigDistrict, $GigPostalCode, $GigCity ).'</td>
            </tr>
            <tr>
              <td>'.$L_GigVenue.':</td>
              <td>'.$GigVenue.'</td>
            </tr>
            <tr>
              <td>'.$L_GigVenueURL.':</td>
              <td>'.$GigVenueURL.'</td>
            </tr>
            <tr>
              <td>'.$L_GigEvent.':</td>
              <td>'.$GigEvent.'</td>
            </tr>
            <tr>
              <td>'.$L_GigEventURL.':</td>
              <td>'.$GigEventURL.'</td>
            </tr>
            <tr>
              <td>'.$L_GigEntranceFee.':</td>
              <td>'.$GigEntranceFee.'</td>
            </tr>
            <tr>
              <td>'.$L_GigOrganizer.':</td>
              <td>'.$GigOrganizer.'</td>
            </tr>
            <tr>
              <td>'.$L_GigOrganizerURL.':</td>
              <td>'.$GigOrganizerURL.'</td>
            </tr>
            <tr>
              <td>'.$L_GigArtist.':</td>
              <td>'.$GigArtist.'</td>
            </tr>
            <tr>
              <td>'.$L_GigArtistURL.':</td>
              <td>'.$GigArtistURL.'</td>
            </tr>
            <tr>
              <td>'.$L_GigLineup.':</td>
              <td>'.$GigLineup.'</td>
            </tr>
            <tr>
              <td>'.$L_GigVisitors.':</td>
              <td>'.$GigVisitors.'</td>
            </tr>
            <tr>
              <td>'.$L_GigStageBuilding.':</td>
              <td>'.$GigStageBuilding.'</td>
            </tr>
            <tr>
              <td>'.$L_GigBeginning.':</td>
              <td>'.$GigBeginning.'</td>
            </tr>
            <tr>
              <td>'.$L_GigDuration.':</td>
              <td>'.$GigDuration.'</td>
            </tr>
            <tr>
              <td>'.$L_GigEnding.':</td>
              <td>'.$GigEnding.'</td>
            </tr>
            <tr>
              <td>'.$L_GigNotes.':</td>
              <td>'.$GigNotes.'</td>
            </tr>
            <tr>
              <td>'.$L_GigStatus.':</td>
              <td>'.${'L_GigStatus'.$GigStatus}.'</td>
            </tr>
            <tr>
              <td>'.$L_GigIsPrivate.':</td>
              <td>';
                if ( $GigIsPrivate ) echo $L_091;
                else echo $L_092;
                echo '
              </td>
            </tr>
            <tr>
              <td>'.$L_GigDateOfAdding.':</td>
              <td>'.DatumMitUhrzeitAusTimestamp($GigDateOfAdding);
                if ($GigAddedFrom) echo ' (';
                echo $GigAddedFrom;
                if ($GigAddedFrom) echo ')';
                echo'
              </td>
            </tr>
            <tr>
              <td>'.$L_GigDateOfLastEdit.':</td>
              <td>'.DatumMitUhrzeitAusTimestamp($GigDateOfLastEdit);
                if ($GigLastEditor) echo ' (';
                echo $GigLastEditor;
                if ($GigLastEditor) echo ')';
                echo'
              </td>
            </tr>
          </table>
          <a href="javascript:window.print()"><img src="images/print.gif" alt="'.$L_008.'" title="'.$L_008.'" /></a>
          <br />
          <input type="button" value="'.$L_Button04.'" onclick="history.go(-1)" class="button" />';
        // Inhalt zuende
  }
?>
